<?php
declare(strict_types=1);

namespace FiloBlu\Refilo\Remote;

use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Indexer\ActionInterface;
use Magento\Framework\Mview\ActionInterface as MviewActionInterface;
use Psr\Log\LoggerInterface;

/**
 * Class StockIndexer
 * @package FiloBlu\Refilo\Remote
 */
class StockIndexerBridge implements ActionInterface, MviewActionInterface
{

    const INDEXER_ID = 'beehive_stock_bridge';

    const BEEHIVE_STOCK_CL_TABLE = 'beehive_stock_cl';
    /**
     * @var ResourceConnection
     */
    private $connection;
    /**
     * @var LoggerInterface
     */
    private $logger;



    /**
     * @param ResourceConnection $connection
     * @param LoggerInterface $logger
     */
    public function __construct(
        ResourceConnection          $connection,
        LoggerInterface             $logger)
    {

        $this->connection = $connection;
        $this->logger = $logger;
    }

    /**
     *
     */
    public function executeFull()
    {
        $this->execute(null);
    }

    /**
     * @param string[] $skus
     */
    public function execute($skus)
    {
        try {
            $connection = $this->connection->getConnection();
            $query = $connection->select()
                ->from('catalog_product_entity', ['entity_id' => new \Zend_Db_Expr("entity_id")]);
            if ($skus) {
                $query->where("sku IN (?)", $skus);
            }
            $productIds = $connection->fetchAll($query);
            $connection->insertMultiple(self::BEEHIVE_STOCK_CL_TABLE, $productIds);
        } catch (\Exception $e) {
            $this->logger->critical("FiloBlu Refilo Beehive Stock Bridge:" . $e->getMessage());
        }
    }


    /**
     * @param array $ids
     */
    public function executeList(array $ids)
    {
        $this->execute($ids);
    }

    /**
     * @param string $sku
     */
    public function executeRow($sku)
    {
        $this->execute([$sku]);
    }

}

